==> instagram_hashtag_fetcher-8.x-1.0.tar.gz: instagram_hashtag_fetcher/src/Entity/InstagramPictureEntity.php <==
<?php

namespace Drupal\instagram_pictures\Entity;

use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Entity\EntityChangedTrait;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\user\UserInterface;

/**
 * Defines the Instagram Picture Entity entity.
 *
 * @ingroup instagram_pictures
 *
 * @ContentEntityType(
 *   id = "instagram_picture_entity",
 *   label = @Translation("Instagram Picture Entity"),
 *   handlers = {
 *     "view_builder" = "Drupal\Core\Entity\EntityViewBuilder",
 *     "list_builder" = "Drupal\instagram_pictures\InstagramPictureEntityListBuilder",
 *     "views_data" = "Drupal\instagram_pictures\Entity\InstagramPictureEntityViewsData",
 *     "translation" = "Drupal\instagram_pictures\InstagramPictureEntityTranslationHandler",
 *
 *     "form" = {
 *       "default" = "Drupal\instagram_pictures\Form\InstagramPictureEntityForm",
 *       "add" = "Drupal\instagram_pictures\Form\InstagramPictureEntityForm",
 *       "edit" = "Drupal\instagram_pictures\Form\InstagramPictureEntityForm",
 *       "delete" = "Drupal\instagram_pictures\Form\InstagramPictureEntityDeleteForm",
 *     },
 *     "access" = "Drupal\instagram_pictures\InstagramPictureEntityAccessControlHandler",
 *     "route_provider" = {
 *       "html" = "Drupal\instagram_pictures\InstagramPictureEntityHtmlRouteProvider",
 *     },
 *   },
 *   base_table = "instagram_picture_entity",
 *   data_table = "instagram_picture_entity_field_data",
 *   translatable = TRUE,
 *   admin_permission = "administer instagram picture entity entities",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "name",
 *     "uuid" = "uuid",
 *     "uid" = "user_id",
 *     "langcode" = "langcode",
 *     "status" = "status",
 *   },
 *   links = {
 *     "canonical" = "/admin/structure/instagram_picture_entity/{instagram_picture_entity}",
 *     "add-form" = "/admin/structure/instagram_picture_entity/add",
 *     "edit-form" = "/admin/structure/instagram_picture_entity/{instagram_picture_entity}/edit",
 *     "delete-form" = "/admin/structure/instagram_picture_entity/{instagram_picture_entity}/delete",
 *     "collection" = "/admin/structure/instagram_picture_entity",
 *   },
 *   field_ui_base_route = "instagram_picture_entity.settings"
 * )
 */
class InstagramPictureEntity extends ContentEntityBase implements InstagramPictureEntityInterface {

  use EntityChangedTrait;

  /**
   * {@inheritdoc}
   */
  public static function preCreate(EntityStorageInterface $storage_controller, array &$values) {
    parent::preCreate($storage_controller, $values);
    $values += [
      'user_id' => \Drupal::currentUser()->id(),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getName() {
    return $this->get('name')->value;
  }

  /**
   * {@inheritdoc}
   */
  public function setName($name) {
    $this->set('name', $name);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getCreatedTime() {
    return $this->get('created')->value;
  }

  /**
   * {@inheritdoc}
   */
  public function setCreatedTime($timestamp) {
    $this->set('created', $timestamp);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getOwner() {
    return $this->get('user_id')->entity;
  }

  /**
   * {@inheritdoc}
   */
  public function getOwnerId() {
    return $this->get('user_id')->target_id;
  }

  /**
   * {@inheritdoc}
   */
  public function setOwnerId($uid) {
    $this->set('user_id', $uid);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function setOwner(UserInterface $account) {
    $this->set('user_id', $account->id());
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function isPublished() {
    return (bool) $this->getEntityKey('status');
  }

  /**
   * {@inheritdoc}
   */
  public function setPublished($published) {
    $this->set('status', $published ? TRUE : FALSE);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type) {
    $fields = parent::baseFieldDefinitions($entity_type);

    $fields['user_id'] = BaseFieldDefinition::create('entity_reference')
      ->setLabel(t('Authored by'))
      ->setDescription(t('The user ID of author of the Instagram Picture Entity entity.'))
      ->setRevisionable(TRUE)
      ->setSetting('target_type', 'user')
      ->setSetting('handler', 'default')
      ->setTranslatable(TRUE)
      ->setDisplayOptions('view', [
        'label' => 'hidden',
        'type' => 'author',
        'weight' => 0,
      ])
      ->setDisplayOptions('form', [
        'type' => 'entity_reference_autocomplete',
        'weight' => 5,
        'settings' => [
          'match_operator' => 'CONTAINS',
          'size' => '60',
          'autocomplete_type' => 'tags',
          'placeholder' => '',
        ],
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['name'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Title'))
      ->setDescription(t('The title of the Instagram Picture Entity entity.'))
      ->setSettings([
        'max_length' => 50,
        'text_processing' => 0,
      ])
      ->setDefaultValue('')
      ->setDisplayOptions('view', [
        'label' => 'above',
        'type' => 'string',
        'weight' => -4,
      ])
      ->setDisplayOptions('form', [
        'type' => 'string_textfield',
        'weight' => -4,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE)
      ->setRequired(TRUE);

    $fields['status'] = BaseFieldDefinition::create('boolean')
      ->setLabel(t('Publishing status'))
      ->setDescription(t('A boolean indicating whether the Instagram Picture Entity is published.'))
      ->setDefaultValue(TRUE)
      ->setDisplayOptions('form', [
        'type' => 'boolean_checkbox',
        'weight' => -3,
      ]);

    $fields['created'] = BaseFieldDefinition::create('created')
      ->setLabel(t('Created'))
      ->setDescription(t('The time that the entity was created.'));

    $fields['changed'] = BaseFieldDefinition::create('changed')
      ->setLabel(t('Changed'))
      ->setDescription(t('The time that the entity was last edited.'));

    return $fields;
  }

}

==> instagram_hashtag_fetcher-8.x-1.12.tar.gz: instagram_hashtag_fetcher/src/Entity/InstagramPictureEntity.php <==
<?php

namespace Drupal\instagram_hashtag_fetcher\Entity;

use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Entity\EntityChangedTrait;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\user\UserInterface;

/**
 * Defines the Instagram Picture Entity entity.
 *
 * @ingroup instagram_pictures
 *
 * @ContentEntityType(
 *   id = "instagram_picture_entity",
 *   label = @Translation("Instagram Picture Entity"),
 *   handlers = {
 *     "view_builder" = "Drupal\Core\Entity\EntityViewBuilder",
 *     "list_builder" = "Drupal\instagram_hashtag_fetcher\InstagramPictureEntityListBuilder",
 *     "views_data" = "Drupal\instagram_hashtag_fetcher\Entity\InstagramPictureEntityViewsData",
 *     "translation" = "Drupal\instagram_hashtag_fetcher\InstagramPictureEntityTranslationHandler",
 *
 *     "form" = {
 *       "default" = "Drupal\instagram_hashtag_fetcher\Form\InstagramPictureEntityForm",
 *       "add" = "Drupal\instagram_hashtag_fetcher\Form\InstagramPictureEntityForm",
 *       "edit" = "Drupal\instagram_hashtag_fetcher\Form\InstagramPictureEntityForm",
 *       "delete" = "Drupal\instagram_hashtag_fetcher\Form\InstagramPictureEntityDeleteForm",
 *     },
 *     "access" = "Drupal\instagram_hashtag_fetcher\InstagramPictureEntityAccessControlHandler",
 *     "route_provider" = {
 *       "html" = "Drupal\instagram_hashtag_fetcher\InstagramPictureEntityHtmlRouteProvider",
 *     },
 *   },
 *   base_table = "instagram_picture_entity",
 *   data_table = "instagram_picture_entity_field_data",
 *   translatable = TRUE,
 *   admin_permission = "administer instagram picture entity entities",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "name",
 *     "uuid" = "uuid",
 *     "uid" = "user_id",
 *     "langcode" = "langcode",
 *     "status" = "status",
 *   },
 *   links = {
 *     "canonical" = "/admin/structure/instagram_picture_entity/{instagram_picture_entity}",
 *     "add-form" = "/admin/structure/instagram_picture_entity/add",
 *     "edit-form" = "/admin/structure/instagram_picture_entity/{instagram_picture_entity}/edit",
 *     "delete-form" = "/admin/structure/instagram_picture_entity/{instagram_picture_entity}/delete",
 *     "collection" = "/admin/structure/instagram_picture_entity",
 *   },
 *   field_ui_base_route = "instagram_picture_entity.settings"
 * )
 */
class InstagramPictureEntity extends ContentEntityBase implements InstagramPictureEntityInterface {

  use EntityChangedTrait;

  /**
   * {@inheritdoc}
   */
  public static function preCreate(EntityStorageInterface $storage_controller, array &$values) {
    parent::preCreate($storage_controller, $values);
    $values += [
      'user_id' => \Drupal::currentUser()->id(),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getName() {
    return $this->get('name')->value;
  }

  /**
   * {@inheritdoc}
   */
  public function setName($name) {
    $this->set('name', $name);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getCreatedTime() {
    return $this->get('created')->value;
  }

  /**
   * {@inheritdoc}
   */
  public function setCreatedTime($timestamp) {
    $this->set('created', $timestamp);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getOwner() {
    return $this->get('user_id')->entity;
  }

  /**
   * {@inheritdoc}
   */
  public function getOwnerId() {
    return $this->get('user_id')->target_id;
  }

  /**
   * {@inheritdoc}
   */
  public function setOwnerId($uid) {
    $this->set('user_id', $uid);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function setOwner(UserInterface $account) {
    $this->set('user_id', $account->id());
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function isPublished() {
    return (bool) $this->getEntityKey('status');
  }

  /**
   * {@inheritdoc}
   */
  public function setPublished($published) {
    $this->set('status', $published ? TRUE : FALSE);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type) {
    $fields = parent::baseFieldDefinitions($entity_type);

    $fields['user_id'] = BaseFieldDefinition::create('entity_reference')
      ->setLabel(t('Authored by'))
      ->setDescription(t('The user ID of author of the Instagram Picture Entity entity.'))
      ->setRevisionable(TRUE)
      ->setSetting('target_type', 'user')
      ->setSetting('handler', 'default')
      ->setTranslatable(TRUE)
      ->setDisplayOptions('view', [
        'label' => 'hidden',
        'type' => 'author',
        'weight' => 0,
      ])
      ->setDisplayOptions('form', [
        'type' => 'entity_reference_autocomplete',
        'weight' => 5,
        'settings' => [
          'match_operator' => 'CONTAINS',
          'size' => '60',
          'autocomplete_type' => 'tags',
          'placeholder' => '',
        ],
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['name'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Title'))
      ->setDescription(t('The title of the Instagram Picture Entity entity.'))
      ->setSettings([
        'max_length' => 50,
        'text_processing' => 0,
      ])
      ->setDefaultValue('')
      ->setDisplayOptions('view', [
        'label' => 'above',
        'type' => 'string',
        'weight' => -4,
      ])
      ->setDisplayOptions('form', [
        'type' => 'string_textfield',
        'weight' => -4,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE)
      ->setRequired(TRUE);

    $fields['status'] = BaseFieldDefinition::create('boolean')
      ->setLabel(t('Publishing status'))
      ->setDescription(t('A boolean indicating whether the Instagram Picture Entity is published.'))
      ->setDefaultValue(TRUE)
      ->setDisplayOptions('form', [
        'type' => 'boolean_checkbox',
        'weight' => -3,
      ]);

    $fields['created'] = BaseFieldDefinition::create('created')
      ->setLabel(t('Created'))
      ->setDescription(t('The time that the entity was created.'));

    $fields['changed'] = BaseFieldDefinition::create('changed')
      ->setLabel(t('Changed'))
      ->setDescription(t('The time that the entity was last edited.'));

    return $fields;
  }

}
